# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing_extensions import Self

from slurmrestpy.models.v0042_bf_exit_fields import V0042BfExitFields
from slurmrestpy.models.v0042_schedule_exit_fields import V0042ScheduleExitFields
from slurmrestpy.models.v0042_stats_msg_rpc_dump import V0042StatsMsgRpcDump
from slurmrestpy.models.v0042_stats_msg_rpc_queue import V0042StatsMsgRpcQueue
from slurmrestpy.models.v0042_stats_msg_rpc_type import V0042StatsMsgRpcType
from slurmrestpy.models.v0042_stats_msg_rpc_user import V0042StatsMsgRpcUser
from slurmrestpy.models.v0042_uint64_no_val_struct import V0042Uint64NoValStruct


class V0042StatsMsg(BaseModel):
    """
    V0042StatsMsg
    """  # noqa: E501

    parts_packed: Optional[StrictInt] = Field(
        default=None, description="Zero if only RPC statistic included"
    )
    req_time: Optional[V0042Uint64NoValStruct] = None
    req_time_start: Optional[V0042Uint64NoValStruct] = None
    server_thread_count: Optional[StrictInt] = Field(
        default=None, description="Number of current active slurmctld threads"
    )
    agent_queue_size: Optional[StrictInt] = Field(
        default=None,
        description="Number of enqueued outgoing RPC requests in an internal retry list",
    )
    agent_count: Optional[StrictInt] = Field(
        default=None, description="Number of agent threads"
    )
    agent_thread_count: Optional[StrictInt] = Field(
        default=None,
        description="Total number of active threads created by all agent threads",
    )
    dbd_agent_queue_size: Optional[StrictInt] = Field(
        default=None, description="Number of messages for SlurmDBD that are queued"
    )
    gettimeofday_latency: Optional[StrictInt] = Field(
        default=None,
        description="Latency of 1000 calls to the gettimeofday() syscall in microseconds, as measured at controller startup",
    )
    schedule_cycle_max: Optional[StrictInt] = Field(
        default=None,
        description="Max time of any scheduling cycle in microseconds since last reset",
    )
    schedule_cycle_last: Optional[StrictInt] = Field(
        default=None, description="Time in microseconds for last scheduling cycle"
    )
    schedule_cycle_sum: Optional[StrictInt] = Field(
        default=None,
        description="Total run time in microseconds for all scheduling cycles since last reset",
    )
    schedule_cycle_total: Optional[StrictInt] = Field(
        default=None, description="Number of scheduling cycles since last reset"
    )
    schedule_cycle_mean: Optional[StrictInt] = Field(
        default=None,
        description="Mean time in microseconds for all scheduling cycles since last reset",
    )
    schedule_cycle_mean_depth: Optional[StrictInt] = Field(
        default=None,
        description="Mean of the number of jobs processed in a scheduling cycle",
    )
    schedule_cycle_per_minute: Optional[StrictInt] = Field(
        default=None, description="Number of scheduling executions per minute"
    )
    schedule_cycle_depth: Optional[StrictInt] = Field(
        default=None, description="Total number of jobs processed in scheduling cycles"
    )
    schedule_exit: Optional[V0042ScheduleExitFields] = None
    schedule_queue_length: Optional[StrictInt] = Field(
        default=None, description="Number of jobs pending in queue"
    )
    jobs_submitted: Optional[StrictInt] = Field(
        default=None, description="Number of jobs submitted since last reset"
    )
    jobs_started: Optional[StrictInt] = Field(
        default=None, description="Number of jobs started since last reset"
    )
    jobs_completed: Optional[StrictInt] = Field(
        default=None, description="Number of jobs completed since last reset"
    )
    jobs_canceled: Optional[StrictInt] = Field(
        default=None, description="Number of jobs canceled since the last reset"
    )
    jobs_failed: Optional[StrictInt] = Field(
        default=None,
        description="Number of jobs failed due to slurmd or other internal issues since last reset",
    )
    jobs_pending: Optional[StrictInt] = Field(
        default=None,
        description="Number of jobs pending at the time of listed in job_state_ts",
    )
    jobs_running: Optional[StrictInt] = Field(
        default=None,
        description="Number of jobs running at the time of listed in job_state_ts",
    )
    job_states_ts: Optional[V0042Uint64NoValStruct] = None
    bf_backfilled_jobs: Optional[StrictInt] = Field(
        default=None,
        description="Number of jobs started through backfilling since last slurm start",
    )
    bf_last_backfilled_jobs: Optional[StrictInt] = Field(
        default=None,
        description="Number of jobs started through backfilling since last reset",
    )
    bf_backfilled_het_jobs: Optional[StrictInt] = Field(
        default=None,
        description="Number of heterogeneous job components started through backfilling since last Slurm start",
    )
    bf_cycle_counter: Optional[StrictInt] = Field(
        default=None,
        description="Number of backfill scheduling cycles since last reset",
    )
    bf_cycle_mean: Optional[StrictInt] = Field(
        default=None,
        description="Mean time in microseconds of backfilling scheduling cycles since last reset",
    )
    bf_depth_mean: Optional[StrictInt] = Field(
        default=None,
        description="Mean number of eligible to run jobs processed during all backfilling scheduling cycles since last reset",
    )
    bf_depth_mean_try: Optional[StrictInt] = Field(
        default=None,
        description="The subset of Depth Mean that the backfill scheduler attempted to schedule",
    )
    bf_cycle_sum: Optional[StrictInt] = Field(
        default=None,
        description="Total time in microseconds of backfilling scheduling cycles since last reset",
    )
    bf_cycle_last: Optional[StrictInt] = Field(
        default=None,
        description="Execution time in microseconds of last backfill scheduling cycle",
    )
    bf_cycle_max: Optional[StrictInt] = Field(
        default=None,
        description="Execution time in microseconds of longest backfill scheduling cycle",
    )
    bf_exit: Optional[V0042BfExitFields] = None
    bf_last_depth: Optional[StrictInt] = Field(
        default=None,
        description="Number of processed jobs during last backfilling scheduling cycle",
    )
    bf_last_depth_try: Optional[StrictInt] = Field(
        default=None,
        description="Number of processed jobs during last backfilling scheduling cycle that had a chance to start using available resources",
    )
    bf_depth_sum: Optional[StrictInt] = Field(
        default=None,
        description="Total number of jobs processed during all backfilling scheduling cycles since last reset",
    )
    bf_depth_try_sum: Optional[StrictInt] = Field(
        default=None,
        description="Subset of bf_depth_sum that the backfill scheduler attempted to schedule",
    )
    bf_queue_len: Optional[StrictInt] = Field(
        default=None,
        description="Number of jobs pending to be processed by backfilling algorithm",
    )
    bf_queue_len_mean: Optional[StrictInt] = Field(
        default=None,
        description="Mean number of jobs pending to be processed by backfilling algorithm",
    )
    bf_queue_len_sum: Optional[StrictInt] = Field(
        default=None,
        description="Total number of jobs pending to be processed by backfilling algorithm since last reset",
    )
    bf_table_size: Optional[StrictInt] = Field(
        default=None,
        description="Number of different time slots tested by the backfill scheduler in its last iteration",
    )
    bf_table_size_sum: Optional[StrictInt] = Field(
        default=None,
        description="Total number of different time slots tested by the backfill scheduler",
    )
    bf_table_size_mean: Optional[StrictInt] = Field(
        default=None,
        description="Mean number of different time slots tested by the backfill scheduler",
    )
    bf_when_last_cycle: Optional[V0042Uint64NoValStruct] = None
    bf_active: Optional[StrictBool] = Field(
        default=None, description="Backfill scheduler currently running"
    )
    rpcs_by_message_type: Optional[List[V0042StatsMsgRpcType]] = Field(
        default=None, description="RPCs by type"
    )
    rpcs_by_user: Optional[List[V0042StatsMsgRpcUser]] = Field(
        default=None, description="RPCs by user"
    )
    pending_rpcs: Optional[List[V0042StatsMsgRpcQueue]] = Field(
        default=None, description="Pending RPCs"
    )
    pending_rpcs_by_hostlist: Optional[List[V0042StatsMsgRpcDump]] = Field(
        default=None, description="Pending RPCs by hostlist"
    )
    __properties: ClassVar[List[str]] = [
        "parts_packed",
        "req_time",
        "req_time_start",
        "server_thread_count",
        "agent_queue_size",
        "agent_count",
        "agent_thread_count",
        "dbd_agent_queue_size",
        "gettimeofday_latency",
        "schedule_cycle_max",
        "schedule_cycle_last",
        "schedule_cycle_sum",
        "schedule_cycle_total",
        "schedule_cycle_mean",
        "schedule_cycle_mean_depth",
        "schedule_cycle_per_minute",
        "schedule_cycle_depth",
        "schedule_exit",
        "schedule_queue_length",
        "jobs_submitted",
        "jobs_started",
        "jobs_completed",
        "jobs_canceled",
        "jobs_failed",
        "jobs_pending",
        "jobs_running",
        "job_states_ts",
        "bf_backfilled_jobs",
        "bf_last_backfilled_jobs",
        "bf_backfilled_het_jobs",
        "bf_cycle_counter",
        "bf_cycle_mean",
        "bf_depth_mean",
        "bf_depth_mean_try",
        "bf_cycle_sum",
        "bf_cycle_last",
        "bf_cycle_max",
        "bf_exit",
        "bf_last_depth",
        "bf_last_depth_try",
        "bf_depth_sum",
        "bf_depth_try_sum",
        "bf_queue_len",
        "bf_queue_len_mean",
        "bf_queue_len_sum",
        "bf_table_size",
        "bf_table_size_sum",
        "bf_table_size_mean",
        "bf_when_last_cycle",
        "bf_active",
        "rpcs_by_message_type",
        "rpcs_by_user",
        "pending_rpcs",
        "pending_rpcs_by_hostlist",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042StatsMsg from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of req_time
        if self.req_time:
            _dict["req_time"] = self.req_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of req_time_start
        if self.req_time_start:
            _dict["req_time_start"] = self.req_time_start.to_dict()
        # override the default output from pydantic by calling `to_dict()` of schedule_exit
        if self.schedule_exit:
            _dict["schedule_exit"] = self.schedule_exit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of job_states_ts
        if self.job_states_ts:
            _dict["job_states_ts"] = self.job_states_ts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bf_exit
        if self.bf_exit:
            _dict["bf_exit"] = self.bf_exit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bf_when_last_cycle
        if self.bf_when_last_cycle:
            _dict["bf_when_last_cycle"] = self.bf_when_last_cycle.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in rpcs_by_message_type (list)
        _items = []
        if self.rpcs_by_message_type:
            for _item_rpcs_by_message_type in self.rpcs_by_message_type:
                if _item_rpcs_by_message_type:
                    _items.append(_item_rpcs_by_message_type.to_dict())
            _dict["rpcs_by_message_type"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in rpcs_by_user (list)
        _items = []
        if self.rpcs_by_user:
            for _item_rpcs_by_user in self.rpcs_by_user:
                if _item_rpcs_by_user:
                    _items.append(_item_rpcs_by_user.to_dict())
            _dict["rpcs_by_user"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in pending_rpcs (list)
        _items = []
        if self.pending_rpcs:
            for _item_pending_rpcs in self.pending_rpcs:
                if _item_pending_rpcs:
                    _items.append(_item_pending_rpcs.to_dict())
            _dict["pending_rpcs"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in pending_rpcs_by_hostlist (list)
        _items = []
        if self.pending_rpcs_by_hostlist:
            for _item_pending_rpcs_by_hostlist in self.pending_rpcs_by_hostlist:
                if _item_pending_rpcs_by_hostlist:
                    _items.append(_item_pending_rpcs_by_hostlist.to_dict())
            _dict["pending_rpcs_by_hostlist"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042StatsMsg from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "parts_packed": obj.get("parts_packed"),
                "req_time": V0042Uint64NoValStruct.from_dict(obj["req_time"])
                if obj.get("req_time") is not None
                else None,
                "req_time_start": V0042Uint64NoValStruct.from_dict(
                    obj["req_time_start"]
                )
                if obj.get("req_time_start") is not None
                else None,
                "server_thread_count": obj.get("server_thread_count"),
                "agent_queue_size": obj.get("agent_queue_size"),
                "agent_count": obj.get("agent_count"),
                "agent_thread_count": obj.get("agent_thread_count"),
                "dbd_agent_queue_size": obj.get("dbd_agent_queue_size"),
                "gettimeofday_latency": obj.get("gettimeofday_latency"),
                "schedule_cycle_max": obj.get("schedule_cycle_max"),
                "schedule_cycle_last": obj.get("schedule_cycle_last"),
                "schedule_cycle_sum": obj.get("schedule_cycle_sum"),
                "schedule_cycle_total": obj.get("schedule_cycle_total"),
                "schedule_cycle_mean": obj.get("schedule_cycle_mean"),
                "schedule_cycle_mean_depth": obj.get("schedule_cycle_mean_depth"),
                "schedule_cycle_per_minute": obj.get("schedule_cycle_per_minute"),
                "schedule_cycle_depth": obj.get("schedule_cycle_depth"),
                "schedule_exit": V0042ScheduleExitFields.from_dict(obj["schedule_exit"])
                if obj.get("schedule_exit") is not None
                else None,
                "schedule_queue_length": obj.get("schedule_queue_length"),
                "jobs_submitted": obj.get("jobs_submitted"),
                "jobs_started": obj.get("jobs_started"),
                "jobs_completed": obj.get("jobs_completed"),
                "jobs_canceled": obj.get("jobs_canceled"),
                "jobs_failed": obj.get("jobs_failed"),
                "jobs_pending": obj.get("jobs_pending"),
                "jobs_running": obj.get("jobs_running"),
                "job_states_ts": V0042Uint64NoValStruct.from_dict(obj["job_states_ts"])
                if obj.get("job_states_ts") is not None
                else None,
                "bf_backfilled_jobs": obj.get("bf_backfilled_jobs"),
                "bf_last_backfilled_jobs": obj.get("bf_last_backfilled_jobs"),
                "bf_backfilled_het_jobs": obj.get("bf_backfilled_het_jobs"),
                "bf_cycle_counter": obj.get("bf_cycle_counter"),
                "bf_cycle_mean": obj.get("bf_cycle_mean"),
                "bf_depth_mean": obj.get("bf_depth_mean"),
                "bf_depth_mean_try": obj.get("bf_depth_mean_try"),
                "bf_cycle_sum": obj.get("bf_cycle_sum"),
                "bf_cycle_last": obj.get("bf_cycle_last"),
                "bf_cycle_max": obj.get("bf_cycle_max"),
                "bf_exit": V0042BfExitFields.from_dict(obj["bf_exit"])
                if obj.get("bf_exit") is not None
                else None,
                "bf_last_depth": obj.get("bf_last_depth"),
                "bf_last_depth_try": obj.get("bf_last_depth_try"),
                "bf_depth_sum": obj.get("bf_depth_sum"),
                "bf_depth_try_sum": obj.get("bf_depth_try_sum"),
                "bf_queue_len": obj.get("bf_queue_len"),
                "bf_queue_len_mean": obj.get("bf_queue_len_mean"),
                "bf_queue_len_sum": obj.get("bf_queue_len_sum"),
                "bf_table_size": obj.get("bf_table_size"),
                "bf_table_size_sum": obj.get("bf_table_size_sum"),
                "bf_table_size_mean": obj.get("bf_table_size_mean"),
                "bf_when_last_cycle": V0042Uint64NoValStruct.from_dict(
                    obj["bf_when_last_cycle"]
                )
                if obj.get("bf_when_last_cycle") is not None
                else None,
                "bf_active": obj.get("bf_active"),
                "rpcs_by_message_type": [
                    V0042StatsMsgRpcType.from_dict(_item)
                    for _item in obj["rpcs_by_message_type"]
                ]
                if obj.get("rpcs_by_message_type") is not None
                else None,
                "rpcs_by_user": [
                    V0042StatsMsgRpcUser.from_dict(_item)
                    for _item in obj["rpcs_by_user"]
                ]
                if obj.get("rpcs_by_user") is not None
                else None,
                "pending_rpcs": [
                    V0042StatsMsgRpcQueue.from_dict(_item)
                    for _item in obj["pending_rpcs"]
                ]
                if obj.get("pending_rpcs") is not None
                else None,
                "pending_rpcs_by_hostlist": [
                    V0042StatsMsgRpcDump.from_dict(_item)
                    for _item in obj["pending_rpcs_by_hostlist"]
                ]
                if obj.get("pending_rpcs_by_hostlist") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_partition_resp import V0041OpenapiPartitionResp


class TestV0041OpenapiPartitionResp(unittest.TestCase):
    """V0041OpenapiPartitionResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiPartitionResp:
        """Test V0041OpenapiPartitionResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiPartitionResp`
        """
        model = V0041OpenapiPartitionResp()
        if include_optional:
            return V0041OpenapiPartitionResp(
                partitions = [
                    slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner.v0_0_41_openapi_partition_resp_partitions_inner(
                        nodes = slurmrestpy.models.v0_0_42_partition_info_nodes.v0_0_42_partition_info_nodes(
                            allowed_allocation = '',
                            configured = '',
                            total = 56, ),
                        accounts = slurmrestpy.models.v0_0_42_partition_info_accounts.v0_0_42_partition_info_accounts(
                            allowed = '',
                            deny = '', ),
                        groups = slurmrestpy.models.v0_0_42_partition_info_groups.v0_0_42_partition_info_groups(
                            allowed = '', ),
                        qos = slurmrestpy.models.v0_0_42_partition_info_qos.v0_0_42_partition_info_qos(
                            allowed = '',
                            deny = '',
                            assigned = '', ),
                        alternate = '',
                        tres = slurmrestpy.models.v0_0_42_partition_info_tres.v0_0_42_partition_info_tres(
                            billing_weights = '',
                            configured = '', ),
                        cluster = '',
                        select_type = [
                            'CPU'
                            ],
                        cpus = slurmrestpy.models.v0_0_42_partition_info_cpus.v0_0_42_partition_info_cpus(
                            task_binding = 56,
                            total = 56, ),
                        defaults = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults.v0_0_41_openapi_partition_resp_partitions_inner_defaults(
                            memory_per_cpu = 56,
                            partition_memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_cpu.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_cpu(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            partition_memory_per_node = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_node.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_node(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            time = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults_time.v0_0_41_openapi_partition_resp_partitions_inner_defaults_time(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            job = '', ),
                        grace_time = 56,
                        maximums = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums.v0_0_41_openapi_partition_resp_partitions_inner_maximums(
                            cpus_per_node = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_node.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_node(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            cpus_per_socket = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_socket.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_socket(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            memory_per_cpu = 56,
                            shares = 56,
                            oversubscribe = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_oversubscribe.v0_0_41_openapi_partition_resp_partitions_inner_maximums_oversubscribe(
                                jobs = 56,
                                flags = [
                                    'force'
                                    ], ),
                            over_time_limit = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_over_time_limit.v0_0_41_openapi_partition_resp_partitions_inner_maximums_over_time_limit(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        minimums = slurmrestpy.models.v0_0_42_partition_info_minimums.v0_0_42_partition_info_minimums(),
                        name = '',
                        node_sets = '',
                        priority = slurmrestpy.models.v0_0_42_partition_info_priority.v0_0_42_partition_info_priority(
                            job_factor = 56,
                            tier = 56, ),
                        timeouts = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_timeouts.v0_0_41_openapi_partition_resp_partitions_inner_timeouts(
                            resume = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_resume.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_resume(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            suspend = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_suspend.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_suspend(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        partition = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_partition.v0_0_41_openapi_partition_resp_partitions_inner_partition(
                            state = [
                                'INACTIVE'
                                ], ),
                        suspend_time = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_suspend_time.v0_0_41_openapi_partition_resp_partitions_inner_suspend_time(
                            set = True,
                            infinite = True,
                            number = 56, ), )
                    ],
                last_update = slurmrestpy.models.v0_0_41_openapi_partition_resp_last_update.v0_0_41_openapi_partition_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiPartitionResp(
                partitions = [
                    slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner.v0_0_41_openapi_partition_resp_partitions_inner(
                        nodes = slurmrestpy.models.v0_0_42_partition_info_nodes.v0_0_42_partition_info_nodes(
                            allowed_allocation = '',
                            configured = '',
                            total = 56, ),
                        accounts = slurmrestpy.models.v0_0_42_partition_info_accounts.v0_0_42_partition_info_accounts(
                            allowed = '',
                            deny = '', ),
                        groups = slurmrestpy.models.v0_0_42_partition_info_groups.v0_0_42_partition_info_groups(
                            allowed = '', ),
                        qos = slurmrestpy.models.v0_0_42_partition_info_qos.v0_0_42_partition_info_qos(
                            allowed = '',
                            deny = '',
                            assigned = '', ),
                        alternate = '',
                        tres = slurmrestpy.models.v0_0_42_partition_info_tres.v0_0_42_partition_info_tres(
                            billing_weights = '',
                            configured = '', ),
                        cluster = '',
                        select_type = [
                            'CPU'
                            ],
                        cpus = slurmrestpy.models.v0_0_42_partition_info_cpus.v0_0_42_partition_info_cpus(
                            task_binding = 56,
                            total = 56, ),
                        defaults = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults.v0_0_41_openapi_partition_resp_partitions_inner_defaults(
                            memory_per_cpu = 56,
                            partition_memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_cpu.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_cpu(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            partition_memory_per_node = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_node.v0_0_41_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_node(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            time = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_defaults_time.v0_0_41_openapi_partition_resp_partitions_inner_defaults_time(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            job = '', ),
                        grace_time = 56,
                        maximums = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums.v0_0_41_openapi_partition_resp_partitions_inner_maximums(
                            cpus_per_node = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_node.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_node(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            cpus_per_socket = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_socket.v0_0_41_openapi_partition_resp_partitions_inner_maximums_cpus_per_socket(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            memory_per_cpu = 56,
                            shares = 56,
                            oversubscribe = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_oversubscribe.v0_0_41_openapi_partition_resp_partitions_inner_maximums_oversubscribe(
                                jobs = 56,
                                flags = [
                                    'force'
                                    ], ),
                            over_time_limit = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_maximums_over_time_limit.v0_0_41_openapi_partition_resp_partitions_inner_maximums_over_time_limit(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        minimums = slurmrestpy.models.v0_0_42_partition_info_minimums.v0_0_42_partition_info_minimums(),
                        name = '',
                        node_sets = '',
                        priority = slurmrestpy.models.v0_0_42_partition_info_priority.v0_0_42_partition_info_priority(
                            job_factor = 56,
                            tier = 56, ),
                        timeouts = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_timeouts.v0_0_41_openapi_partition_resp_partitions_inner_timeouts(
                            resume = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_resume.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_resume(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            suspend = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_suspend.v0_0_41_openapi_partition_resp_partitions_inner_timeouts_suspend(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        partition = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_partition.v0_0_41_openapi_partition_resp_partitions_inner_partition(
                            state = [
                                'INACTIVE'
                                ], ),
                        suspend_time = slurmrestpy.models.v0_0_41_openapi_partition_resp_partitions_inner_suspend_time.v0_0_41_openapi_partition_resp_partitions_inner_suspend_time(
                            set = True,
                            infinite = True,
                            number = 56, ), )
                    ],
                last_update = slurmrestpy.models.v0_0_41_openapi_partition_resp_last_update.v0_0_41_openapi_partition_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
        )
        """

    def testV0041OpenapiPartitionResp(self):
        """Test V0041OpenapiPartitionResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict
from typing_extensions import Self

from slurmrestpy.models.v0042_qos_limits_min_tres_per import V0042QosLimitsMinTresPer
from slurmrestpy.models.v0042_tres import V0042Tres


class V0042AssocMaxTresMinutes(BaseModel):
    """
    V0042AssocMaxTresMinutes
    """  # noqa: E501

    total: Optional[List[V0042Tres]] = None
    per: Optional[V0042QosLimitsMinTresPer] = None
    __properties: ClassVar[List[str]] = ["total", "per"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042AssocMaxTresMinutes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in total (list)
        _items = []
        if self.total:
            for _item_total in self.total:
                if _item_total:
                    _items.append(_item_total.to_dict())
            _dict["total"] = _items
        # override the default output from pydantic by calling `to_dict()` of per
        if self.per:
            _dict["per"] = self.per.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042AssocMaxTresMinutes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "total": [V0042Tres.from_dict(_item) for _item in obj["total"]]
                if obj.get("total") is not None
                else None,
                "per": V0042QosLimitsMinTresPer.from_dict(obj["per"])
                if obj.get("per") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_job_info_resp import V0041OpenapiJobInfoResp


class TestV0041OpenapiJobInfoResp(unittest.TestCase):
    """V0041OpenapiJobInfoResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiJobInfoResp:
        """Test V0041OpenapiJobInfoResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiJobInfoResp`
        """
        model = V0041OpenapiJobInfoResp()
        if include_optional:
            return V0041OpenapiJobInfoResp(
                jobs = [
                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner.v0_0_41_openapi_job_info_resp_jobs_inner(
                        account = '',
                        accrue_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_accrue_time.v0_0_41_openapi_job_info_resp_jobs_inner_accrue_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        admin_comment = '',
                        allocating_node = '',
                        array_job_id = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_array_job_id.v0_0_41_openapi_job_info_resp_jobs_inner_array_job_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        array_task_id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        array_max_tasks = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_array_max_tasks.v0_0_41_openapi_job_info_resp_jobs_inner_array_max_tasks(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        array_task_string = '',
                        association_id = 56,
                        batch_features = '',
                        batch_flag = True,
                        batch_host = '',
                        flags = [
                            'KILL_INVALID_DEPENDENCY'
                            ],
                        burst_buffer = '',
                        burst_buffer_state = '',
                        cluster = '',
                        cluster_features = '',
                        command = '',
                        comment = '',
                        container = '',
                        container_id = '',
                        contiguous = True,
                        core_spec = 56,
                        thread_spec = 56,
                        cores_per_socket = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cores_per_socket.v0_0_41_openapi_job_info_resp_jobs_inner_cores_per_socket(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        billable_tres = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_billable_tres.v0_0_41_openapi_job_info_resp_jobs_inner_billable_tres(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        cpus_per_task = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpus_per_task.v0_0_41_openapi_job_info_resp_jobs_inner_cpus_per_task(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpu_frequency_minimum = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpu_frequency_maximum = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpu_frequency_governor = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_governor.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_governor(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpus_per_tres = '',
                        cron = '',
                        deadline = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_deadline.v0_0_41_openapi_job_info_resp_jobs_inner_deadline(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        delay_boot = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_delay_boot.v0_0_41_openapi_job_info_resp_jobs_inner_delay_boot(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        dependency = '',
                        derived_exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code(
                            status = [
                                'INVALID'
                                ],
                            return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                                id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                                    set = True,
                                    infinite = True,
                                    number = 56, ),
                                name = '', ), ),
                        eligible_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_eligible_time.v0_0_41_openapi_job_info_resp_jobs_inner_eligible_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        end_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_end_time.v0_0_41_openapi_job_info_resp_jobs_inner_end_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        excluded_nodes = '',
                        exit_code = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_exit_code.v0_0_41_openapi_job_info_resp_jobs_inner_exit_code(),
                        extra = '',
                        failed_node = '',
                        features = '',
                        federation_origin = '',
                        federation_siblings_active = '',
                        federation_siblings_viable = '',
                        gres_detail = [
                            ''
                            ],
                        group_id = 56,
                        group_name = '',
                        het_job_id = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_het_job_id.v0_0_41_openapi_job_info_resp_jobs_inner_het_job_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        het_job_id_set = '',
                        het_job_offset = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        job_id = 56,
                        job_resources = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources(
                            select_type = [
                                'CPU'
                                ],
                            nodes = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes(
                                count = 56,
                                list = '',
                                whole = True,
                                allocation = [
                                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner(
                                        index = 56,
                                        name = '',
                                        cpus = slurmrestpy.models.v0_0_42_job_res_node_cpus.v0_0_42_job_res_node_cpus(
                                            count = 56,
                                            used = 56, ),
                                        memory = slurmrestpy.models.v0_0_42_job_res_node_memory.v0_0_42_job_res_node_memory(
                                            used = 56,
                                            allocated = 56, ),
                                        sockets = [
                                            slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner(
                                                index = 56,
                                                cores = [
                                                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner(
                                                        index = 56,
                                                        status = [
                                                            'INVALID'
                                                            ], )
                                                    ], )
                                            ], )
                                    ], ),
                            cpus = 56,
                            threads_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        job_size_str = [
                            ''
                            ],
                        job_state = [
                            'PENDING'
                            ],
                        last_sched_evaluation = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_last_sched_evaluation.v0_0_41_openapi_job_info_resp_jobs_inner_last_sched_evaluation(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        licenses = '',
                        mail_type = [
                            'BEGIN'
                            ],
                        mail_user = '',
                        max_cpus = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_max_cpus.v0_0_41_openapi_job_info_resp_jobs_inner_max_cpus(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        max_nodes = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_max_nodes.v0_0_41_openapi_job_info_resp_jobs_inner_max_nodes(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        mcs_label = '',
                        memory_per_tres = '',
                        name = '',
                        network = '',
                        nodes = '',
                        nice = 56,
                        tasks_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_core(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_tres = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_tres.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_tres(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_socket = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_socket.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_socket(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_board = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_board.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_board(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpus = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpus.v0_0_41_openapi_job_info_resp_jobs_inner_cpus(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        node_count = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_node_count.v0_0_41_openapi_job_info_resp_jobs_inner_node_count(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks.v0_0_41_openapi_job_info_resp_jobs_inner_tasks(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        partition = '',
                        prefer = '',
                        memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        minimum_cpus_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        minimum_tmp_disk_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        power = slurmrestpy.models.v0_0_42_job_info_power.v0_0_42_job_info_power(),
                        preempt_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_preempt_time.v0_0_41_openapi_job_info_resp_jobs_inner_preempt_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        preemptable_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_preemptable_time.v0_0_41_openapi_job_info_resp_jobs_inner_preemptable_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        pre_sus_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_pre_sus_time.v0_0_41_openapi_job_info_resp_jobs_inner_pre_sus_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        hold = True,
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        profile = [
                            'NOT_SET'
                            ],
                        qos = '',
                        reboot = True,
                        required_nodes = '',
                        minimum_switches = 56,
                        requeue = True,
                        resize_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_resize_time.v0_0_41_openapi_job_info_resp_jobs_inner_resize_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        restart_cnt = 56,
                        resv_name = '',
                        scheduled_nodes = '',
                        selinux_context = '',
                        shared = [
                            'none'
                            ],
                        exclusive = [
                            'true'
                            ],
                        oversubscribe = True,
                        show_flags = [
                            'ALL'
                            ],
                        sockets_per_board = 56,
                        sockets_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_sockets_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_sockets_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        start_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_start_time.v0_0_41_openapi_job_info_resp_jobs_inner_start_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        state_description = '',
                        state_reason = '',
                        standard_error = '',
                        standard_input = '',
                        standard_output = '',
                        submit_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_submit_time.v0_0_41_openapi_job_info_resp_jobs_inner_submit_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        suspend_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_suspend_time.v0_0_41_openapi_job_info_resp_jobs_inner_suspend_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        system_comment = '',
                        time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        threads_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_threads_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_threads_per_core(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres_bind = '',
                        tres_freq = '',
                        tres_per_job = '',
                        tres_per_node = '',
                        tres_per_socket = '',
                        tres_per_task = '',
                        tres_req_str = '',
                        tres_alloc_str = '',
                        user_id = 56,
                        user_name = '',
                        maximum_switch_wait_time = 56,
                        wckey = '',
                        current_working_directory = '', )
                    ],
                last_backfill = slurmrestpy.models.v0_0_41_openapi_job_info_resp_last_backfill.v0_0_41_openapi_job_info_resp_last_backfill(
                    set = True,
                    infinite = True,
                    number = 56, ),
                last_update = slurmrestpy.models.v0_0_41_openapi_job_info_resp_last_update.v0_0_41_openapi_job_info_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiJobInfoResp(
                jobs = [
                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner.v0_0_41_openapi_job_info_resp_jobs_inner(
                        account = '',
                        accrue_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_accrue_time.v0_0_41_openapi_job_info_resp_jobs_inner_accrue_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        admin_comment = '',
                        allocating_node = '',
                        array_job_id = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_array_job_id.v0_0_41_openapi_job_info_resp_jobs_inner_array_job_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        array_task_id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        array_max_tasks = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_array_max_tasks.v0_0_41_openapi_job_info_resp_jobs_inner_array_max_tasks(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        array_task_string = '',
                        association_id = 56,
                        batch_features = '',
                        batch_flag = True,
                        batch_host = '',
                        flags = [
                            'KILL_INVALID_DEPENDENCY'
                            ],
                        burst_buffer = '',
                        burst_buffer_state = '',
                        cluster = '',
                        cluster_features = '',
                        command = '',
                        comment = '',
                        container = '',
                        container_id = '',
                        contiguous = True,
                        core_spec = 56,
                        thread_spec = 56,
                        cores_per_socket = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cores_per_socket.v0_0_41_openapi_job_info_resp_jobs_inner_cores_per_socket(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        billable_tres = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_billable_tres.v0_0_41_openapi_job_info_resp_jobs_inner_billable_tres(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        cpus_per_task = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpus_per_task.v0_0_41_openapi_job_info_resp_jobs_inner_cpus_per_task(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpu_frequency_minimum = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpu_frequency_maximum = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpu_frequency_governor = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_governor.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_governor(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpus_per_tres = '',
                        cron = '',
                        deadline = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_deadline.v0_0_41_openapi_job_info_resp_jobs_inner_deadline(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        delay_boot = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_delay_boot.v0_0_41_openapi_job_info_resp_jobs_inner_delay_boot(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        dependency = '',
                        derived_exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code(
                            status = [
                                'INVALID'
                                ],
                            return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                                id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                                    set = True,
                                    infinite = True,
                                    number = 56, ),
                                name = '', ), ),
                        eligible_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_eligible_time.v0_0_41_openapi_job_info_resp_jobs_inner_eligible_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        end_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_end_time.v0_0_41_openapi_job_info_resp_jobs_inner_end_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        excluded_nodes = '',
                        exit_code = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_exit_code.v0_0_41_openapi_job_info_resp_jobs_inner_exit_code(),
                        extra = '',
                        failed_node = '',
                        features = '',
                        federation_origin = '',
                        federation_siblings_active = '',
                        federation_siblings_viable = '',
                        gres_detail = [
                            ''
                            ],
                        group_id = 56,
                        group_name = '',
                        het_job_id = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_het_job_id.v0_0_41_openapi_job_info_resp_jobs_inner_het_job_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        het_job_id_set = '',
                        het_job_offset = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        job_id = 56,
                        job_resources = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources(
                            select_type = [
                                'CPU'
                                ],
                            nodes = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes(
                                count = 56,
                                list = '',
                                whole = True,
                                allocation = [
                                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner(
                                        index = 56,
                                        name = '',
                                        cpus = slurmrestpy.models.v0_0_42_job_res_node_cpus.v0_0_42_job_res_node_cpus(
                                            count = 56,
                                            used = 56, ),
                                        memory = slurmrestpy.models.v0_0_42_job_res_node_memory.v0_0_42_job_res_node_memory(
                                            used = 56,
                                            allocated = 56, ),
                                        sockets = [
                                            slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner(
                                                index = 56,
                                                cores = [
                                                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner(
                                                        index = 56,
                                                        status = [
                                                            'INVALID'
                                                            ], )
                                                    ], )
                                            ], )
                                    ], ),
                            cpus = 56,
                            threads_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        job_size_str = [
                            ''
                            ],
                        job_state = [
                            'PENDING'
                            ],
                        last_sched_evaluation = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_last_sched_evaluation.v0_0_41_openapi_job_info_resp_jobs_inner_last_sched_evaluation(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        licenses = '',
                        mail_type = [
                            'BEGIN'
                            ],
                        mail_user = '',
                        max_cpus = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_max_cpus.v0_0_41_openapi_job_info_resp_jobs_inner_max_cpus(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        max_nodes = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_max_nodes.v0_0_41_openapi_job_info_resp_jobs_inner_max_nodes(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        mcs_label = '',
                        memory_per_tres = '',
                        name = '',
                        network = '',
                        nodes = '',
                        nice = 56,
                        tasks_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_core(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_tres = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_tres.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_tres(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_socket = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_socket.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_socket(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks_per_board = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_board.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_board(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpus = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpus.v0_0_41_openapi_job_info_resp_jobs_inner_cpus(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        node_count = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_node_count.v0_0_41_openapi_job_info_resp_jobs_inner_node_count(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tasks = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks.v0_0_41_openapi_job_info_resp_jobs_inner_tasks(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        partition = '',
                        prefer = '',
                        memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        minimum_cpus_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        minimum_tmp_disk_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        power = slurmrestpy.models.v0_0_42_job_info_power.v0_0_42_job_info_power(),
                        preempt_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_preempt_time.v0_0_41_openapi_job_info_resp_jobs_inner_preempt_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        preemptable_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_preemptable_time.v0_0_41_openapi_job_info_resp_jobs_inner_preemptable_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        pre_sus_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_pre_sus_time.v0_0_41_openapi_job_info_resp_jobs_inner_pre_sus_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        hold = True,
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        profile = [
                            'NOT_SET'
                            ],
                        qos = '',
                        reboot = True,
                        required_nodes = '',
                        minimum_switches = 56,
                        requeue = True,
                        resize_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_resize_time.v0_0_41_openapi_job_info_resp_jobs_inner_resize_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        restart_cnt = 56,
                        resv_name = '',
                        scheduled_nodes = '',
                        selinux_context = '',
                        shared = [
                            'none'
                            ],
                        exclusive = [
                            'true'
                            ],
                        oversubscribe = True,
                        show_flags = [
                            'ALL'
                            ],
                        sockets_per_board = 56,
                        sockets_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_sockets_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_sockets_per_node(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        start_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_start_time.v0_0_41_openapi_job_info_resp_jobs_inner_start_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        state_description = '',
                        state_reason = '',
                        standard_error = '',
                        standard_input = '',
                        standard_output = '',
                        submit_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_submit_time.v0_0_41_openapi_job_info_resp_jobs_inner_submit_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        suspend_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_suspend_time.v0_0_41_openapi_job_info_resp_jobs_inner_suspend_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        system_comment = '',
                        time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        threads_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_threads_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_threads_per_core(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres_bind = '',
                        tres_freq = '',
                        tres_per_job = '',
                        tres_per_node = '',
                        tres_per_socket = '',
                        tres_per_task = '',
                        tres_req_str = '',
                        tres_alloc_str = '',
                        user_id = 56,
                        user_name = '',
                        maximum_switch_wait_time = 56,
                        wckey = '',
                        current_working_directory = '', )
                    ],
                last_backfill = slurmrestpy.models.v0_0_41_openapi_job_info_resp_last_backfill.v0_0_41_openapi_job_info_resp_last_backfill(
                    set = True,
                    infinite = True,
                    number = 56, ),
                last_update = slurmrestpy.models.v0_0_41_openapi_job_info_resp_last_update.v0_0_41_openapi_job_info_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
        )
        """

    def testV0041OpenapiJobInfoResp(self):
        """Test V0041OpenapiJobInfoResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0041_update_node_msg_resume_after import (
    V0041UpdateNodeMsgResumeAfter,
)
from slurmrestpy.models.v0041_update_node_msg_weight import V0041UpdateNodeMsgWeight


class V0041UpdateNodeMsg(BaseModel):
    """
    V0041UpdateNodeMsg
    """  # noqa: E501

    comment: Optional[StrictStr] = Field(default=None, description="Arbitrary comment")
    cpu_bind: Optional[StrictInt] = Field(
        default=None, description="Default method for binding tasks to allocated CPUs"
    )
    extra: Optional[StrictStr] = Field(
        default=None,
        description="Arbitrary string used for node filtering if extra constraints are enabled",
    )
    features: Optional[List[StrictStr]] = Field(
        default=None, description="Available features"
    )
    features_act: Optional[List[StrictStr]] = Field(
        default=None, description="Currently active features"
    )
    gres: Optional[StrictStr] = Field(default=None, description="Generic resources")
    address: Optional[List[StrictStr]] = Field(
        default=None, description="NodeAddr, used to establish a communication path"
    )
    hostname: Optional[List[StrictStr]] = Field(
        default=None, description="NodeHostname"
    )
    name: Optional[List[StrictStr]] = Field(default=None, description="NodeName")
    state: Optional[List[StrictStr]] = Field(
        default=None, description="New state to assign to the node"
    )
    reason: Optional[StrictStr] = Field(
        default=None, description="Reason for node being DOWN or DRAINING"
    )
    reason_uid: Optional[StrictStr] = Field(
        default=None,
        description="User ID to associate with the reason (needed if user root is sending message)",
    )
    resume_after: Optional[V0041UpdateNodeMsgResumeAfter] = None
    weight: Optional[V0041UpdateNodeMsgWeight] = None
    __properties: ClassVar[List[str]] = [
        "comment",
        "cpu_bind",
        "extra",
        "features",
        "features_act",
        "gres",
        "address",
        "hostname",
        "name",
        "state",
        "reason",
        "reason_uid",
        "resume_after",
        "weight",
    ]

    @field_validator("state")
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "INVALID",
                    "UNKNOWN",
                    "DOWN",
                    "IDLE",
                    "ALLOCATED",
                    "ERROR",
                    "MIXED",
                    "FUTURE",
                    "RESERVED",
                    "UNDRAIN",
                    "CLOUD",
                    "RESUME",
                    "DRAIN",
                    "COMPLETING",
                    "NOT_RESPONDING",
                    "POWERED_DOWN",
                    "FAIL",
                    "POWERING_UP",
                    "MAINTENANCE",
                    "REBOOT_REQUESTED",
                    "REBOOT_CANCELED",
                    "POWERING_DOWN",
                    "DYNAMIC_FUTURE",
                    "REBOOT_ISSUED",
                    "PLANNED",
                    "INVALID_REG",
                    "POWER_DOWN",
                    "POWER_UP",
                    "POWER_DRAIN",
                    "DYNAMIC_NORM",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('INVALID', 'UNKNOWN', 'DOWN', 'IDLE', 'ALLOCATED', 'ERROR', 'MIXED', 'FUTURE', 'RESERVED', 'UNDRAIN', 'CLOUD', 'RESUME', 'DRAIN', 'COMPLETING', 'NOT_RESPONDING', 'POWERED_DOWN', 'FAIL', 'POWERING_UP', 'MAINTENANCE', 'REBOOT_REQUESTED', 'REBOOT_CANCELED', 'POWERING_DOWN', 'DYNAMIC_FUTURE', 'REBOOT_ISSUED', 'PLANNED', 'INVALID_REG', 'POWER_DOWN', 'POWER_UP', 'POWER_DRAIN', 'DYNAMIC_NORM')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041UpdateNodeMsg from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of resume_after
        if self.resume_after:
            _dict["resume_after"] = self.resume_after.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weight
        if self.weight:
            _dict["weight"] = self.weight.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041UpdateNodeMsg from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "comment": obj.get("comment"),
                "cpu_bind": obj.get("cpu_bind"),
                "extra": obj.get("extra"),
                "features": obj.get("features"),
                "features_act": obj.get("features_act"),
                "gres": obj.get("gres"),
                "address": obj.get("address"),
                "hostname": obj.get("hostname"),
                "name": obj.get("name"),
                "state": obj.get("state"),
                "reason": obj.get("reason"),
                "reason_uid": obj.get("reason_uid"),
                "resume_after": V0041UpdateNodeMsgResumeAfter.from_dict(
                    obj["resume_after"]
                )
                if obj.get("resume_after") is not None
                else None,
                "weight": V0041UpdateNodeMsgWeight.from_dict(obj["weight"])
                if obj.get("weight") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_consumed import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed,
)


class TestV0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(
    unittest.TestCase
):
    """V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed:
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed`
        """
        model = V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(
                max = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                min = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                average = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                total = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ]
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(self):
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_cluster_rec import V0040ClusterRec


class TestV0040ClusterRec(unittest.TestCase):
    """V0040ClusterRec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040ClusterRec:
        """Test V0040ClusterRec
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040ClusterRec`
        """
        model = V0040ClusterRec()
        if include_optional:
            return V0040ClusterRec(
                controller = slurmrestpy.models.v0_0_42_cluster_rec_controller.v0_0_42_cluster_rec_controller(
                    host = '',
                    port = 56, ),
                flags = [
                    'REGISTERING'
                    ],
                name = '',
                nodes = '',
                select_plugin = '',
                associations = slurmrestpy.models.v0_0_40_cluster_rec_associations.v0_0_40_cluster_rec_associations(
                    root = slurmrestpy.models.v0/0/40_assoc_short.v0.0.40_assoc_short(
                        account = '',
                        cluster = '',
                        partition = '',
                        user = '',
                        id = 56, ), ),
                rpc_version = 56,
                tres = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ]
            )
        else:
            return V0040ClusterRec(
        )
        """

    def testV0040ClusterRec(self):
        """Test V0040ClusterRec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_accounts_add_cond import V0040AccountsAddCond


class TestV0040AccountsAddCond(unittest.TestCase):
    """V0040AccountsAddCond unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040AccountsAddCond:
        """Test V0040AccountsAddCond
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040AccountsAddCond`
        """
        model = V0040AccountsAddCond()
        if include_optional:
            return V0040AccountsAddCond(
                accounts = [
                    ''
                    ],
                association = slurmrestpy.models.v0/0/40_assoc_rec_set.v0.0.40_assoc_rec_set(
                    comment = '',
                    defaultqos = '',
                    grpjobs = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    grpjobsaccrue = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    grpsubmitjobs = ,
                    grptres = [
                        slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    grptresmins = [
                        slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, )
                        ],
                    grptresrunmins = ,
                    grpwall = ,
                    maxjobs = ,
                    maxjobsaccrue = ,
                    maxsubmitjobs = ,
                    maxtresminsperjob = ,
                    maxtresrunmins = ,
                    maxtresperjob = ,
                    maxtrespernode = ,
                    maxwalldurationperjob = ,
                    minpriothresh = ,
                    parent = '',
                    priority = ,
                    qoslevel = [
                        ''
                        ],
                    fairshare = 56, ),
                clusters = [
                    ''
                    ]
            )
        else:
            return V0040AccountsAddCond(
                accounts = [
                    ''
                    ],
        )
        """

    def testV0040AccountsAddCond(self):
        """Test V0040AccountsAddCond"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self

from slurmrestpy.models.v0040_assoc_short import V0040AssocShort
from slurmrestpy.models.v0040_job_array import V0040JobArray
from slurmrestpy.models.v0040_job_het import V0040JobHet
from slurmrestpy.models.v0040_job_required import V0040JobRequired
from slurmrestpy.models.v0040_job_state import V0040JobState
from slurmrestpy.models.v0040_job_time import V0040JobTime
from slurmrestpy.models.v0040_job_tres import V0040JobTres
from slurmrestpy.models.v0040_process_exit_code_verbose import (
    V0040ProcessExitCodeVerbose,
)
from slurmrestpy.models.v0040_step import V0040Step
from slurmrestpy.models.v0040_uint32_no_val import V0040Uint32NoVal
from slurmrestpy.models.v0040_wckey_tag_struct import V0040WckeyTagStruct
from slurmrestpy.models.v0042_job_comment import V0042JobComment
from slurmrestpy.models.v0042_job_mcs import V0042JobMcs
from slurmrestpy.models.v0042_job_reservation import V0042JobReservation


class V0040Job(BaseModel):
    """
    V0040Job
    """  # noqa: E501

    account: Optional[StrictStr] = Field(
        default=None, description="Account the job ran under"
    )
    comment: Optional[V0042JobComment] = None
    allocation_nodes: Optional[StrictInt] = Field(
        default=None, description="List of nodes allocated to the job"
    )
    array: Optional[V0040JobArray] = None
    association: Optional[V0040AssocShort] = None
    block: Optional[StrictStr] = Field(
        default=None,
        description="The name of the block to be used (used with Blue Gene systems)",
    )
    cluster: Optional[StrictStr] = Field(default=None, description="Cluster name")
    constraints: Optional[StrictStr] = Field(
        default=None, description="Feature(s) the job requested as a constraint"
    )
    container: Optional[StrictStr] = Field(
        default=None, description="Absolute path to OCI container bundle"
    )
    derived_exit_code: Optional[V0040ProcessExitCodeVerbose] = None
    time: Optional[V0040JobTime] = None
    exit_code: Optional[V0040ProcessExitCodeVerbose] = None
    extra: Optional[StrictStr] = Field(
        default=None,
        description="Arbitrary string used for node filtering if extra constraints are enabled",
    )
    failed_node: Optional[StrictStr] = Field(
        default=None, description="Name of node that caused job failure"
    )
    flags: Optional[List[StrictStr]] = None
    group: Optional[StrictStr] = Field(
        default=None, description="Group ID of the user that owns the job"
    )
    het: Optional[V0040JobHet] = None
    job_id: Optional[StrictInt] = Field(default=None, description="Job ID")
    name: Optional[StrictStr] = Field(default=None, description="Job name")
    licenses: Optional[StrictStr] = Field(
        default=None, description="License(s) required by the job"
    )
    mcs: Optional[V0042JobMcs] = None
    nodes: Optional[StrictStr] = Field(
        default=None, description="Node(s) allocated to the job"
    )
    partition: Optional[StrictStr] = Field(
        default=None, description="Partition assigned to the job"
    )
    hold: Optional[StrictBool] = Field(default=None, description="Job held")
    priority: Optional[V0040Uint32NoVal] = None
    qos: Optional[StrictStr] = Field(
        default=None, description="Quality of Service assigned to the job"
    )
    required: Optional[V0040JobRequired] = None
    kill_request_user: Optional[StrictStr] = Field(
        default=None, description="User ID that requested termination of the job"
    )
    reservation: Optional[V0042JobReservation] = None
    script: Optional[StrictStr] = Field(
        default=None,
        description="Job batch script; only the first component in a HetJob is populated or honored",
    )
    state: Optional[V0040JobState] = None
    steps: Optional[List[V0040Step]] = None
    submit_line: Optional[StrictStr] = Field(
        default=None, description="Command used to submit the job"
    )
    tres: Optional[V0040JobTres] = None
    used_gres: Optional[StrictStr] = Field(
        default=None, description="Generic resources used by job"
    )
    user: Optional[StrictStr] = Field(
        default=None, description="User that owns the job"
    )
    wckey: Optional[V0040WckeyTagStruct] = None
    working_directory: Optional[StrictStr] = Field(
        default=None, description="Path to current working directory"
    )
    __properties: ClassVar[List[str]] = [
        "account",
        "comment",
        "allocation_nodes",
        "array",
        "association",
        "block",
        "cluster",
        "constraints",
        "container",
        "derived_exit_code",
        "time",
        "exit_code",
        "extra",
        "failed_node",
        "flags",
        "group",
        "het",
        "job_id",
        "name",
        "licenses",
        "mcs",
        "nodes",
        "partition",
        "hold",
        "priority",
        "qos",
        "required",
        "kill_request_user",
        "reservation",
        "script",
        "state",
        "steps",
        "submit_line",
        "tres",
        "used_gres",
        "user",
        "wckey",
        "working_directory",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "NONE",
                    "CLEAR_SCHEDULING",
                    "NOT_SET",
                    "STARTED_ON_SUBMIT",
                    "STARTED_ON_SCHEDULE",
                    "STARTED_ON_BACKFILL",
                    "START_RECEIVED",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('NONE', 'CLEAR_SCHEDULING', 'NOT_SET', 'STARTED_ON_SUBMIT', 'STARTED_ON_SCHEDULE', 'STARTED_ON_BACKFILL', 'START_RECEIVED')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0040Job from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of comment
        if self.comment:
            _dict["comment"] = self.comment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of array
        if self.array:
            _dict["array"] = self.array.to_dict()
        # override the default output from pydantic by calling `to_dict()` of association
        if self.association:
            _dict["association"] = self.association.to_dict()
        # override the default output from pydantic by calling `to_dict()` of derived_exit_code
        if self.derived_exit_code:
            _dict["derived_exit_code"] = self.derived_exit_code.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time
        if self.time:
            _dict["time"] = self.time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of exit_code
        if self.exit_code:
            _dict["exit_code"] = self.exit_code.to_dict()
        # override the default output from pydantic by calling `to_dict()` of het
        if self.het:
            _dict["het"] = self.het.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mcs
        if self.mcs:
            _dict["mcs"] = self.mcs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        # override the default output from pydantic by calling `to_dict()` of required
        if self.required:
            _dict["required"] = self.required.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reservation
        if self.reservation:
            _dict["reservation"] = self.reservation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of state
        if self.state:
            _dict["state"] = self.state.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in steps (list)
        _items = []
        if self.steps:
            for _item_steps in self.steps:
                if _item_steps:
                    _items.append(_item_steps.to_dict())
            _dict["steps"] = _items
        # override the default output from pydantic by calling `to_dict()` of tres
        if self.tres:
            _dict["tres"] = self.tres.to_dict()
        # override the default output from pydantic by calling `to_dict()` of wckey
        if self.wckey:
            _dict["wckey"] = self.wckey.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0040Job from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "account": obj.get("account"),
                "comment": V0042JobComment.from_dict(obj["comment"])
                if obj.get("comment") is not None
                else None,
                "allocation_nodes": obj.get("allocation_nodes"),
                "array": V0040JobArray.from_dict(obj["array"])
                if obj.get("array") is not None
                else None,
                "association": V0040AssocShort.from_dict(obj["association"])
                if obj.get("association") is not None
                else None,
                "block": obj.get("block"),
                "cluster": obj.get("cluster"),
                "constraints": obj.get("constraints"),
                "container": obj.get("container"),
                "derived_exit_code": V0040ProcessExitCodeVerbose.from_dict(
                    obj["derived_exit_code"]
                )
                if obj.get("derived_exit_code") is not None
                else None,
                "time": V0040JobTime.from_dict(obj["time"])
                if obj.get("time") is not None
                else None,
                "exit_code": V0040ProcessExitCodeVerbose.from_dict(obj["exit_code"])
                if obj.get("exit_code") is not None
                else None,
                "extra": obj.get("extra"),
                "failed_node": obj.get("failed_node"),
                "flags": obj.get("flags"),
                "group": obj.get("group"),
                "het": V0040JobHet.from_dict(obj["het"])
                if obj.get("het") is not None
                else None,
                "job_id": obj.get("job_id"),
                "name": obj.get("name"),
                "licenses": obj.get("licenses"),
                "mcs": V0042JobMcs.from_dict(obj["mcs"])
                if obj.get("mcs") is not None
                else None,
                "nodes": obj.get("nodes"),
                "partition": obj.get("partition"),
                "hold": obj.get("hold"),
                "priority": V0040Uint32NoVal.from_dict(obj["priority"])
                if obj.get("priority") is not None
                else None,
                "qos": obj.get("qos"),
                "required": V0040JobRequired.from_dict(obj["required"])
                if obj.get("required") is not None
                else None,
                "kill_request_user": obj.get("kill_request_user"),
                "reservation": V0042JobReservation.from_dict(obj["reservation"])
                if obj.get("reservation") is not None
                else None,
                "script": obj.get("script"),
                "state": V0040JobState.from_dict(obj["state"])
                if obj.get("state") is not None
                else None,
                "steps": [V0040Step.from_dict(_item) for _item in obj["steps"]]
                if obj.get("steps") is not None
                else None,
                "submit_line": obj.get("submit_line"),
                "tres": V0040JobTres.from_dict(obj["tres"])
                if obj.get("tres") is not None
                else None,
                "used_gres": obj.get("used_gres"),
                "user": obj.get("user"),
                "wckey": V0040WckeyTagStruct.from_dict(obj["wckey"])
                if obj.get("wckey") is not None
                else None,
                "working_directory": obj.get("working_directory"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.api.slurmdb_api import SlurmdbApi


class TestSlurmdbApi(unittest.TestCase):
    """SlurmdbApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SlurmdbApi()

    def tearDown(self) -> None:
        pass

    def test_slurmdb_v0040_delete_account(self) -> None:
        """Test case for slurmdb_v0040_delete_account

        Delete account
        """
        pass

    def test_slurmdb_v0040_delete_association(self) -> None:
        """Test case for slurmdb_v0040_delete_association

        Delete association
        """
        pass

    def test_slurmdb_v0040_delete_associations(self) -> None:
        """Test case for slurmdb_v0040_delete_associations

        Delete associations
        """
        pass

    def test_slurmdb_v0040_delete_cluster(self) -> None:
        """Test case for slurmdb_v0040_delete_cluster

        Delete cluster
        """
        pass

    def test_slurmdb_v0040_delete_single_qos(self) -> None:
        """Test case for slurmdb_v0040_delete_single_qos

        Delete QOS
        """
        pass

    def test_slurmdb_v0040_delete_user(self) -> None:
        """Test case for slurmdb_v0040_delete_user

        Delete user
        """
        pass

    def test_slurmdb_v0040_delete_wckey(self) -> None:
        """Test case for slurmdb_v0040_delete_wckey

        Delete wckey
        """
        pass

    def test_slurmdb_v0040_get_account(self) -> None:
        """Test case for slurmdb_v0040_get_account

        Get account info
        """
        pass

    def test_slurmdb_v0040_get_accounts(self) -> None:
        """Test case for slurmdb_v0040_get_accounts

        Get account list
        """
        pass

    def test_slurmdb_v0040_get_association(self) -> None:
        """Test case for slurmdb_v0040_get_association

        Get association info
        """
        pass

    def test_slurmdb_v0040_get_associations(self) -> None:
        """Test case for slurmdb_v0040_get_associations

        Get association list
        """
        pass

    def test_slurmdb_v0040_get_cluster(self) -> None:
        """Test case for slurmdb_v0040_get_cluster

        Get cluster info
        """
        pass

    def test_slurmdb_v0040_get_clusters(self) -> None:
        """Test case for slurmdb_v0040_get_clusters

        Get cluster list
        """
        pass

    def test_slurmdb_v0040_get_config(self) -> None:
        """Test case for slurmdb_v0040_get_config

        Dump all configuration information
        """
        pass

    def test_slurmdb_v0040_get_diag(self) -> None:
        """Test case for slurmdb_v0040_get_diag

        Get slurmdb diagnostics
        """
        pass

    def test_slurmdb_v0040_get_instance(self) -> None:
        """Test case for slurmdb_v0040_get_instance

        Get instance info
        """
        pass

    def test_slurmdb_v0040_get_instances(self) -> None:
        """Test case for slurmdb_v0040_get_instances

        Get instance list
        """
        pass

    def test_slurmdb_v0040_get_job(self) -> None:
        """Test case for slurmdb_v0040_get_job

        Get job info
        """
        pass

    def test_slurmdb_v0040_get_jobs(self) -> None:
        """Test case for slurmdb_v0040_get_jobs

        Get job list
        """
        pass

    def test_slurmdb_v0040_get_qos(self) -> None:
        """Test case for slurmdb_v0040_get_qos

        Get QOS list
        """
        pass

    def test_slurmdb_v0040_get_single_qos(self) -> None:
        """Test case for slurmdb_v0040_get_single_qos

        Get QOS info
        """
        pass

    def test_slurmdb_v0040_get_tres(self) -> None:
        """Test case for slurmdb_v0040_get_tres

        Get TRES info
        """
        pass

    def test_slurmdb_v0040_get_user(self) -> None:
        """Test case for slurmdb_v0040_get_user

        Get user info
        """
        pass

    def test_slurmdb_v0040_get_users(self) -> None:
        """Test case for slurmdb_v0040_get_users

        Get user list
        """
        pass

    def test_slurmdb_v0040_get_wckey(self) -> None:
        """Test case for slurmdb_v0040_get_wckey

        Get wckey info
        """
        pass

    def test_slurmdb_v0040_get_wckeys(self) -> None:
        """Test case for slurmdb_v0040_get_wckeys

        Get wckey list
        """
        pass

    def test_slurmdb_v0040_post_accounts(self) -> None:
        """Test case for slurmdb_v0040_post_accounts

        Add/update list of accounts
        """
        pass

    def test_slurmdb_v0040_post_accounts_association(self) -> None:
        """Test case for slurmdb_v0040_post_accounts_association

        Add accounts with conditional association
        """
        pass

    def test_slurmdb_v0040_post_associations(self) -> None:
        """Test case for slurmdb_v0040_post_associations

        Set associations info
        """
        pass

    def test_slurmdb_v0040_post_clusters(self) -> None:
        """Test case for slurmdb_v0040_post_clusters

        Get cluster list
        """
        pass

    def test_slurmdb_v0040_post_config(self) -> None:
        """Test case for slurmdb_v0040_post_config

        Load all configuration information
        """
        pass

    def test_slurmdb_v0040_post_qos(self) -> None:
        """Test case for slurmdb_v0040_post_qos

        Add or update QOSs
        """
        pass

    def test_slurmdb_v0040_post_tres(self) -> None:
        """Test case for slurmdb_v0040_post_tres

        Add TRES
        """
        pass

    def test_slurmdb_v0040_post_users(self) -> None:
        """Test case for slurmdb_v0040_post_users

        Update users
        """
        pass

    def test_slurmdb_v0040_post_users_association(self) -> None:
        """Test case for slurmdb_v0040_post_users_association

        Add users with conditional association
        """
        pass

    def test_slurmdb_v0040_post_wckeys(self) -> None:
        """Test case for slurmdb_v0040_post_wckeys

        Add or update wckeys
        """
        pass

    def test_slurmdb_v0041_delete_account(self) -> None:
        """Test case for slurmdb_v0041_delete_account

        Delete account
        """
        pass

    def test_slurmdb_v0041_delete_association(self) -> None:
        """Test case for slurmdb_v0041_delete_association

        Delete association
        """
        pass

    def test_slurmdb_v0041_delete_associations(self) -> None:
        """Test case for slurmdb_v0041_delete_associations

        Delete associations
        """
        pass

    def test_slurmdb_v0041_delete_cluster(self) -> None:
        """Test case for slurmdb_v0041_delete_cluster

        Delete cluster
        """
        pass

    def test_slurmdb_v0041_delete_single_qos(self) -> None:
        """Test case for slurmdb_v0041_delete_single_qos

        Delete QOS
        """
        pass

    def test_slurmdb_v0041_delete_user(self) -> None:
        """Test case for slurmdb_v0041_delete_user

        Delete user
        """
        pass

    def test_slurmdb_v0041_delete_wckey(self) -> None:
        """Test case for slurmdb_v0041_delete_wckey

        Delete wckey
        """
        pass

    def test_slurmdb_v0041_get_account(self) -> None:
        """Test case for slurmdb_v0041_get_account

        Get account info
        """
        pass

    def test_slurmdb_v0041_get_accounts(self) -> None:
        """Test case for slurmdb_v0041_get_accounts

        Get account list
        """
        pass

    def test_slurmdb_v0041_get_association(self) -> None:
        """Test case for slurmdb_v0041_get_association

        Get association info
        """
        pass

    def test_slurmdb_v0041_get_associations(self) -> None:
        """Test case for slurmdb_v0041_get_associations

        Get association list
        """
        pass

    def test_slurmdb_v0041_get_cluster(self) -> None:
        """Test case for slurmdb_v0041_get_cluster

        Get cluster info
        """
        pass

    def test_slurmdb_v0041_get_clusters(self) -> None:
        """Test case for slurmdb_v0041_get_clusters

        Get cluster list
        """
        pass

    def test_slurmdb_v0041_get_config(self) -> None:
        """Test case for slurmdb_v0041_get_config

        Dump all configuration information
        """
        pass

    def test_slurmdb_v0041_get_diag(self) -> None:
        """Test case for slurmdb_v0041_get_diag

        Get slurmdb diagnostics
        """
        pass

    def test_slurmdb_v0041_get_instance(self) -> None:
        """Test case for slurmdb_v0041_get_instance

        Get instance info
        """
        pass

    def test_slurmdb_v0041_get_instances(self) -> None:
        """Test case for slurmdb_v0041_get_instances

        Get instance list
        """
        pass

    def test_slurmdb_v0041_get_job(self) -> None:
        """Test case for slurmdb_v0041_get_job

        Get job info
        """
        pass

    def test_slurmdb_v0041_get_jobs(self) -> None:
        """Test case for slurmdb_v0041_get_jobs

        Get job list
        """
        pass

    def test_slurmdb_v0041_get_qos(self) -> None:
        """Test case for slurmdb_v0041_get_qos

        Get QOS list
        """
        pass

    def test_slurmdb_v0041_get_single_qos(self) -> None:
        """Test case for slurmdb_v0041_get_single_qos

        Get QOS info
        """
        pass

    def test_slurmdb_v0041_get_tres(self) -> None:
        """Test case for slurmdb_v0041_get_tres

        Get TRES info
        """
        pass

    def test_slurmdb_v0041_get_user(self) -> None:
        """Test case for slurmdb_v0041_get_user

        Get user info
        """
        pass

    def test_slurmdb_v0041_get_users(self) -> None:
        """Test case for slurmdb_v0041_get_users

        Get user list
        """
        pass

    def test_slurmdb_v0041_get_wckey(self) -> None:
        """Test case for slurmdb_v0041_get_wckey

        Get wckey info
        """
        pass

    def test_slurmdb_v0041_get_wckeys(self) -> None:
        """Test case for slurmdb_v0041_get_wckeys

        Get wckey list
        """
        pass

    def test_slurmdb_v0041_post_accounts(self) -> None:
        """Test case for slurmdb_v0041_post_accounts

        Add/update list of accounts
        """
        pass

    def test_slurmdb_v0041_post_accounts_association(self) -> None:
        """Test case for slurmdb_v0041_post_accounts_association

        Add accounts with conditional association
        """
        pass

    def test_slurmdb_v0041_post_associations(self) -> None:
        """Test case for slurmdb_v0041_post_associations

        Set associations info
        """
        pass

    def test_slurmdb_v0041_post_clusters(self) -> None:
        """Test case for slurmdb_v0041_post_clusters

        Get cluster list
        """
        pass

    def test_slurmdb_v0041_post_config(self) -> None:
        """Test case for slurmdb_v0041_post_config

        Load all configuration information
        """
        pass

    def test_slurmdb_v0041_post_qos(self) -> None:
        """Test case for slurmdb_v0041_post_qos

        Add or update QOSs
        """
        pass

    def test_slurmdb_v0041_post_tres(self) -> None:
        """Test case for slurmdb_v0041_post_tres

        Add TRES
        """
        pass

    def test_slurmdb_v0041_post_users(self) -> None:
        """Test case for slurmdb_v0041_post_users

        Update users
        """
        pass

    def test_slurmdb_v0041_post_users_association(self) -> None:
        """Test case for slurmdb_v0041_post_users_association

        Add users with conditional association
        """
        pass

    def test_slurmdb_v0041_post_wckeys(self) -> None:
        """Test case for slurmdb_v0041_post_wckeys

        Add or update wckeys
        """
        pass

    def test_slurmdb_v0042_delete_account(self) -> None:
        """Test case for slurmdb_v0042_delete_account

        Delete account
        """
        pass

    def test_slurmdb_v0042_delete_association(self) -> None:
        """Test case for slurmdb_v0042_delete_association

        Delete association
        """
        pass

    def test_slurmdb_v0042_delete_associations(self) -> None:
        """Test case for slurmdb_v0042_delete_associations

        Delete associations
        """
        pass

    def test_slurmdb_v0042_delete_cluster(self) -> None:
        """Test case for slurmdb_v0042_delete_cluster

        Delete cluster
        """
        pass

    def test_slurmdb_v0042_delete_single_qos(self) -> None:
        """Test case for slurmdb_v0042_delete_single_qos

        Delete QOS
        """
        pass

    def test_slurmdb_v0042_delete_user(self) -> None:
        """Test case for slurmdb_v0042_delete_user

        Delete user
        """
        pass

    def test_slurmdb_v0042_delete_wckey(self) -> None:
        """Test case for slurmdb_v0042_delete_wckey

        Delete wckey
        """
        pass

    def test_slurmdb_v0042_get_account(self) -> None:
        """Test case for slurmdb_v0042_get_account

        Get account info
        """
        pass

    def test_slurmdb_v0042_get_accounts(self) -> None:
        """Test case for slurmdb_v0042_get_accounts

        Get account list
        """
        pass

    def test_slurmdb_v0042_get_association(self) -> None:
        """Test case for slurmdb_v0042_get_association

        Get association info
        """
        pass

    def test_slurmdb_v0042_get_associations(self) -> None:
        """Test case for slurmdb_v0042_get_associations

        Get association list
        """
        pass

    def test_slurmdb_v0042_get_cluster(self) -> None:
        """Test case for slurmdb_v0042_get_cluster

        Get cluster info
        """
        pass

    def test_slurmdb_v0042_get_clusters(self) -> None:
        """Test case for slurmdb_v0042_get_clusters

        Get cluster list
        """
        pass

    def test_slurmdb_v0042_get_config(self) -> None:
        """Test case for slurmdb_v0042_get_config

        Dump all configuration information
        """
        pass

    def test_slurmdb_v0042_get_diag(self) -> None:
        """Test case for slurmdb_v0042_get_diag

        Get slurmdb diagnostics
        """
        pass

    def test_slurmdb_v0042_get_instance(self) -> None:
        """Test case for slurmdb_v0042_get_instance

        Get instance info
        """
        pass

    def test_slurmdb_v0042_get_instances(self) -> None:
        """Test case for slurmdb_v0042_get_instances

        Get instance list
        """
        pass

    def test_slurmdb_v0042_get_job(self) -> None:
        """Test case for slurmdb_v0042_get_job

        Get job info
        """
        pass

    def test_slurmdb_v0042_get_jobs(self) -> None:
        """Test case for slurmdb_v0042_get_jobs

        Get job list
        """
        pass

    def test_slurmdb_v0042_get_ping(self) -> None:
        """Test case for slurmdb_v0042_get_ping

        ping test
        """
        pass

    def test_slurmdb_v0042_get_qos(self) -> None:
        """Test case for slurmdb_v0042_get_qos

        Get QOS list
        """
        pass

    def test_slurmdb_v0042_get_single_qos(self) -> None:
        """Test case for slurmdb_v0042_get_single_qos

        Get QOS info
        """
        pass

    def test_slurmdb_v0042_get_tres(self) -> None:
        """Test case for slurmdb_v0042_get_tres

        Get TRES info
        """
        pass

    def test_slurmdb_v0042_get_user(self) -> None:
        """Test case for slurmdb_v0042_get_user

        Get user info
        """
        pass

    def test_slurmdb_v0042_get_users(self) -> None:
        """Test case for slurmdb_v0042_get_users

        Get user list
        """
        pass

    def test_slurmdb_v0042_get_wckey(self) -> None:
        """Test case for slurmdb_v0042_get_wckey

        Get wckey info
        """
        pass

    def test_slurmdb_v0042_get_wckeys(self) -> None:
        """Test case for slurmdb_v0042_get_wckeys

        Get wckey list
        """
        pass

    def test_slurmdb_v0042_post_accounts(self) -> None:
        """Test case for slurmdb_v0042_post_accounts

        Add/update list of accounts
        """
        pass

    def test_slurmdb_v0042_post_accounts_association(self) -> None:
        """Test case for slurmdb_v0042_post_accounts_association

        Add accounts with conditional association
        """
        pass

    def test_slurmdb_v0042_post_associations(self) -> None:
        """Test case for slurmdb_v0042_post_associations

        Set associations info
        """
        pass

    def test_slurmdb_v0042_post_clusters(self) -> None:
        """Test case for slurmdb_v0042_post_clusters

        Get cluster list
        """
        pass

    def test_slurmdb_v0042_post_config(self) -> None:
        """Test case for slurmdb_v0042_post_config

        Load all configuration information
        """
        pass

    def test_slurmdb_v0042_post_qos(self) -> None:
        """Test case for slurmdb_v0042_post_qos

        Add or update QOSs
        """
        pass

    def test_slurmdb_v0042_post_tres(self) -> None:
        """Test case for slurmdb_v0042_post_tres

        Add TRES
        """
        pass

    def test_slurmdb_v0042_post_users(self) -> None:
        """Test case for slurmdb_v0042_post_users

        Update users
        """
        pass

    def test_slurmdb_v0042_post_users_association(self) -> None:
        """Test case for slurmdb_v0042_post_users_association

        Add users with conditional association
        """
        pass

    def test_slurmdb_v0042_post_wckeys(self) -> None:
        """Test case for slurmdb_v0042_post_wckeys

        Add or update wckeys
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0042_cluster_rec_associations import (
    V0042ClusterRecAssociations,
)
from slurmrestpy.models.v0042_cluster_rec_controller import V0042ClusterRecController
from slurmrestpy.models.v0042_tres import V0042Tres


class V0042ClusterRec(BaseModel):
    """
    V0042ClusterRec
    """  # noqa: E501

    controller: Optional[V0042ClusterRecController] = None
    flags: Optional[List[StrictStr]] = None
    name: Optional[StrictStr] = Field(default=None, description="ClusterName")
    nodes: Optional[StrictStr] = Field(default=None, description="Node names")
    select_plugin: Optional[StrictStr] = None
    associations: Optional[V0042ClusterRecAssociations] = None
    rpc_version: Optional[StrictInt] = Field(
        default=None, description="RPC version used in the cluster"
    )
    tres: Optional[List[V0042Tres]] = None
    __properties: ClassVar[List[str]] = [
        "controller",
        "flags",
        "name",
        "nodes",
        "select_plugin",
        "associations",
        "rpc_version",
        "tres",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "REGISTERING",
                    "MULTIPLE_SLURMD",
                    "FRONT_END",
                    "FEDERATION",
                    "EXTERNAL",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('REGISTERING', 'MULTIPLE_SLURMD', 'FRONT_END', 'FEDERATION', 'EXTERNAL')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042ClusterRec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of controller
        if self.controller:
            _dict["controller"] = self.controller.to_dict()
        # override the default output from pydantic by calling `to_dict()` of associations
        if self.associations:
            _dict["associations"] = self.associations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tres (list)
        _items = []
        if self.tres:
            for _item_tres in self.tres:
                if _item_tres:
                    _items.append(_item_tres.to_dict())
            _dict["tres"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042ClusterRec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "controller": V0042ClusterRecController.from_dict(obj["controller"])
                if obj.get("controller") is not None
                else None,
                "flags": obj.get("flags"),
                "name": obj.get("name"),
                "nodes": obj.get("nodes"),
                "select_plugin": obj.get("select_plugin"),
                "associations": V0042ClusterRecAssociations.from_dict(
                    obj["associations"]
                )
                if obj.get("associations") is not None
                else None,
                "rpc_version": obj.get("rpc_version"),
                "tres": [V0042Tres.from_dict(_item) for _item in obj["tres"]]
                if obj.get("tres") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0040_user_default import V0040UserDefault
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_accounts_inner_associations_inner import (
    V0041OpenapiSlurmdbdConfigRespAccountsInnerAssociationsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_accounts_inner_coordinators_inner import (
    V0041OpenapiSlurmdbdConfigRespAccountsInnerCoordinatorsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner_wckeys_inner import (
    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInner,
)


class V0041OpenapiSlurmdbdConfigRespUsersInner(BaseModel):
    """
    V0041OpenapiSlurmdbdConfigRespUsersInner
    """  # noqa: E501

    administrator_level: Optional[List[StrictStr]] = Field(
        default=None, description="AdminLevel granted to the user"
    )
    associations: Optional[
        List[V0041OpenapiSlurmdbdConfigRespAccountsInnerAssociationsInner]
    ] = Field(default=None, description="Associations created for this user")
    coordinators: Optional[
        List[V0041OpenapiSlurmdbdConfigRespAccountsInnerCoordinatorsInner]
    ] = Field(default=None, description="Accounts this user is a coordinator for")
    default: Optional[V0040UserDefault] = None
    flags: Optional[List[StrictStr]] = Field(
        default=None, description="Flags associated with user"
    )
    name: StrictStr = Field(description="User name")
    old_name: Optional[StrictStr] = Field(
        default=None, description="Previous user name"
    )
    wckeys: Optional[List[V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInner]] = Field(
        default=None, description="List of available WCKeys"
    )
    __properties: ClassVar[List[str]] = [
        "administrator_level",
        "associations",
        "coordinators",
        "default",
        "flags",
        "name",
        "old_name",
        "wckeys",
    ]

    @field_validator("administrator_level")
    def administrator_level_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["Not Set", "None", "Operator", "Administrator"]):
                raise ValueError(
                    "each list item must be one of ('Not Set', 'None', 'Operator', 'Administrator')"
                )
        return value

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["NONE", "DELETED"]):
                raise ValueError("each list item must be one of ('NONE', 'DELETED')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdConfigRespUsersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in associations (list)
        _items = []
        if self.associations:
            for _item_associations in self.associations:
                if _item_associations:
                    _items.append(_item_associations.to_dict())
            _dict["associations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in coordinators (list)
        _items = []
        if self.coordinators:
            for _item_coordinators in self.coordinators:
                if _item_coordinators:
                    _items.append(_item_coordinators.to_dict())
            _dict["coordinators"] = _items
        # override the default output from pydantic by calling `to_dict()` of default
        if self.default:
            _dict["default"] = self.default.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in wckeys (list)
        _items = []
        if self.wckeys:
            for _item_wckeys in self.wckeys:
                if _item_wckeys:
                    _items.append(_item_wckeys.to_dict())
            _dict["wckeys"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdConfigRespUsersInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "administrator_level": obj.get("administrator_level"),
                "associations": [
                    V0041OpenapiSlurmdbdConfigRespAccountsInnerAssociationsInner.from_dict(
                        _item
                    )
                    for _item in obj["associations"]
                ]
                if obj.get("associations") is not None
                else None,
                "coordinators": [
                    V0041OpenapiSlurmdbdConfigRespAccountsInnerCoordinatorsInner.from_dict(
                        _item
                    )
                    for _item in obj["coordinators"]
                ]
                if obj.get("coordinators") is not None
                else None,
                "default": V0040UserDefault.from_dict(obj["default"])
                if obj.get("default") is not None
                else None,
                "flags": obj.get("flags"),
                "name": obj.get("name"),
                "old_name": obj.get("old_name"),
                "wckeys": [
                    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInner.from_dict(_item)
                    for _item in obj["wckeys"]
                ]
                if obj.get("wckeys") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_min import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMin,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_priority import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerPriority,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner import (
    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner,
)
from slurmrestpy.models.v0042_assoc_default import V0042AssocDefault


class V0041OpenapiSlurmdbdConfigRespAssociationsInner(BaseModel):
    """
    V0041OpenapiSlurmdbdConfigRespAssociationsInner
    """  # noqa: E501

    accounting: Optional[
        List[V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner]
    ] = Field(
        default=None, description="Accounting records containing related resource usage"
    )
    account: Optional[StrictStr] = Field(default=None, description="Account")
    cluster: Optional[StrictStr] = Field(default=None, description="Cluster name")
    comment: Optional[StrictStr] = Field(default=None, description="Arbitrary comment")
    default: Optional[V0042AssocDefault] = None
    flags: Optional[List[StrictStr]] = Field(
        default=None, description="Flags on the association"
    )
    max: Optional[V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax] = None
    id: Optional[StrictInt] = Field(default=None, description="Unique ID")
    is_default: Optional[StrictBool] = Field(
        default=None, description="Is default association for user"
    )
    lineage: Optional[StrictStr] = Field(
        default=None,
        description="Complete path up the hierarchy to the root association",
    )
    min: Optional[V0041OpenapiSlurmdbdConfigRespAssociationsInnerMin] = None
    parent_account: Optional[StrictStr] = Field(
        default=None, description="Name of parent account"
    )
    partition: Optional[StrictStr] = Field(default=None, description="Partition name")
    priority: Optional[V0041OpenapiSlurmdbdConfigRespAssociationsInnerPriority] = None
    qos: Optional[List[StrictStr]] = Field(
        default=None, description="List of available QOS names"
    )
    shares_raw: Optional[StrictInt] = Field(
        default=None, description="Allocated shares used for fairshare calculation"
    )
    user: StrictStr = Field(description="User name")
    __properties: ClassVar[List[str]] = [
        "accounting",
        "account",
        "cluster",
        "comment",
        "default",
        "flags",
        "max",
        "id",
        "is_default",
        "lineage",
        "min",
        "parent_account",
        "partition",
        "priority",
        "qos",
        "shares_raw",
        "user",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                ["DELETED", "NoUpdate", "Exact", "NoUsersAreCoords", "UsersAreCoords"]
            ):
                raise ValueError(
                    "each list item must be one of ('DELETED', 'NoUpdate', 'Exact', 'NoUsersAreCoords', 'UsersAreCoords')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdConfigRespAssociationsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in accounting (list)
        _items = []
        if self.accounting:
            for _item_accounting in self.accounting:
                if _item_accounting:
                    _items.append(_item_accounting.to_dict())
            _dict["accounting"] = _items
        # override the default output from pydantic by calling `to_dict()` of default
        if self.default:
            _dict["default"] = self.default.to_dict()
        # override the default output from pydantic by calling `to_dict()` of max
        if self.max:
            _dict["max"] = self.max.to_dict()
        # override the default output from pydantic by calling `to_dict()` of min
        if self.min:
            _dict["min"] = self.min.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdConfigRespAssociationsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accounting": [
                    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner.from_dict(
                        _item
                    )
                    for _item in obj["accounting"]
                ]
                if obj.get("accounting") is not None
                else None,
                "account": obj.get("account"),
                "cluster": obj.get("cluster"),
                "comment": obj.get("comment"),
                "default": V0042AssocDefault.from_dict(obj["default"])
                if obj.get("default") is not None
                else None,
                "flags": obj.get("flags"),
                "max": V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax.from_dict(
                    obj["max"]
                )
                if obj.get("max") is not None
                else None,
                "id": obj.get("id"),
                "is_default": obj.get("is_default"),
                "lineage": obj.get("lineage"),
                "min": V0041OpenapiSlurmdbdConfigRespAssociationsInnerMin.from_dict(
                    obj["min"]
                )
                if obj.get("min") is not None
                else None,
                "parent_account": obj.get("parent_account"),
                "partition": obj.get("partition"),
                "priority": V0041OpenapiSlurmdbdConfigRespAssociationsInnerPriority.from_dict(
                    obj["priority"]
                )
                if obj.get("priority") is not None
                else None,
                "qos": obj.get("qos"),
                "shares_raw": obj.get("shares_raw"),
                "user": obj.get("user"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics import (
    V0041OpenapiSlurmdbdStatsRespStatistics,
)


class TestV0041OpenapiSlurmdbdStatsRespStatistics(unittest.TestCase):
    """V0041OpenapiSlurmdbdStatsRespStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdStatsRespStatistics:
        """Test V0041OpenapiSlurmdbdStatsRespStatistics
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdStatsRespStatistics`
        """
        model = V0041OpenapiSlurmdbdStatsRespStatistics()
        if include_optional:
            return V0041OpenapiSlurmdbdStatsRespStatistics(
                time_start = 56,
                rollups = slurmrestpy.models.v0_0_41_openapi_slurmdbd_stats_resp_statistics_rollups.v0_0_41_openapi_slurmdbd_stats_resp_statistics_rollups(
                    hourly = slurmrestpy.models.v0_0_42_rollup_stats_hourly.v0_0_42_rollup_stats_hourly(
                        count = 56,
                        last_run = 56,
                        duration = slurmrestpy.models.v0_0_42_rollup_stats_hourly_duration.v0_0_42_rollup_stats_hourly_duration(
                            last = 56,
                            max = 56,
                            time = 56, ), ),
                    daily = slurmrestpy.models.v0_0_42_rollup_stats_daily.v0_0_42_rollup_stats_daily(
                        count = 56,
                        last_run = 56, ),
                    monthly = slurmrestpy.models.v0_0_42_rollup_stats_monthly.v0_0_42_rollup_stats_monthly(
                        count = 56,
                        last_run = 56, ), ),
                rpcs = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_stats_resp_statistics_rpcs_inner.v0_0_41_openapi_slurmdbd_stats_resp_statistics_RPCs_inner(
                        rpc = '',
                        count = 56,
                        time = slurmrestpy.models.v0_0_42_stats_rpc_time.v0_0_42_stats_rpc_time(
                            average = 56,
                            total = 56, ), )
                    ],
                users = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_stats_resp_statistics_users_inner.v0_0_41_openapi_slurmdbd_stats_resp_statistics_users_inner(
                        user = '',
                        count = 56,
                        time = slurmrestpy.models.v0_0_42_stats_rpc_time.v0_0_42_stats_rpc_time(
                            average = 56,
                            total = 56, ), )
                    ]
            )
        else:
            return V0041OpenapiSlurmdbdStatsRespStatistics(
        )
        """

    def testV0041OpenapiSlurmdbdStatsRespStatistics(self):
        """Test V0041OpenapiSlurmdbdStatsRespStatistics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
